﻿namespace HDLNoCGen
{
    /// <summary>
    /// Интерфейс, описывающий объекты, обладающие прямоугольной формой и поддерживающие XY-маршрутизацию.
    /// </summary>
    internal interface IRectangleLike
    {
        /// <summary>
        /// Генерирует список маршрутов XY для текущего прямоугольного объекта.
        /// </summary>
        /// <param name="token">Токен отмены, позволяющий прервать процесс генерации маршрутов.</param>
        /// <returns>Список, содержащий списки целых чисел, представляющих маршруты XY.  Каждый внутренний список представляет собой отдельный маршрут.</returns>
        /// <exception cref="OperationCanceledException">Выбрасывается, если процесс генерации маршрутов был отменен с помощью токена отмены.</exception>
        List<List<int>> Generate_XY_routing(CancellationToken token);

        /// <summary>
        /// Возвращает список существующих путей для XY-маршрутизации.
        /// </summary>
        /// <returns>Список, содержащий списки целых чисел, представляющих пути для XY-маршрутизации.  Каждый внутренний список представляет собой отдельный путь.</returns>
        List<List<int>> Get_ways_routing_XY();
    }
}