﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace HDLNoCGen
{
    /// <summary>
    /// Класс, представляющий метаданные проекта.
    /// Содержит информацию о названии проекта.
    /// </summary>
    public class ProjectMetadata
    {
        /// <summary>
        /// Название проекта.
        /// </summary>
        /// <value>
        /// Строковое значение, представляющее название проекта.
        /// </value>
        public string name { get; set; }

        /// <summary>
        /// Конструктор класса ProjectMetadata.
        /// Инициализирует название проекта пустой строкой.
        /// </summary>
        public ProjectMetadata ()
        {
            /// <summary>
            /// Инициализирует название проекта пустой строкой.
            /// </summary>
            name = "";
        }
    }

    /// <summary>
    /// Класс, представляющий метаданные, связанные с сериализацией графа и генерацией Verilog.
    /// </summary>
    public class GraphVerilogMetadata
    {
        /// <summary>
        /// Флаг, указывающий, был ли сериализован граф.
        /// </summary>
        /// <value>
        /// true, если граф был сериализован; в противном случае — false.
        /// </value>
        public bool graphSerialized { get; set; }
        /// <summary>
        /// Флаг, указывающий, был ли сгенерирован Verilog код.
        /// </summary>
        /// <value>
        /// true, если Verilog код был сгенерирован; в противном случае — false.
        /// </value>
        public bool verilogGenerated { get; set; }

        /// <summary>
        /// Конструктор класса GraphVerilogMetadata.
        /// Инициализирует флаги сериализации графа и генерации Verilog в значение false.
        /// </summary>
        public GraphVerilogMetadata ()
        {
            /// <summary>
            /// Инициализирует флаг сериализации графа в false.
            /// </summary>
            graphSerialized = false;
            /// <summary>
            /// Инициализирует флаг генерации Verilog в false.
            /// </summary>
            verilogGenerated = false;
        }
    }

    /// <summary>
    /// Класс, представляющий метаданные, связанные с компиляцией в Quartus.
    /// </summary>
    public class QuartusMetadata
    {
        /// <summary>
        /// Флаг, указывающий, была ли выполнена компиляция в Quartus.
        /// </summary>
        /// <value>
        /// true, если компиляция в Quartus была выполнена; в противном случае — false.
        /// </value>
        public bool quartusCompiled { get; set; }
        /// <summary>
        /// Название устройства, для которого выполнялась компиляция в Quartus.
        /// </summary>
        /// <value>
        /// Строковое значение, представляющее название устройства.
        /// </value>
        public string deviceName { get; set; }

        /// <summary>
        /// Конструктор класса QuartusMetadata.
        /// Инициализирует флаг компиляции в Quartus в значение false и название устройства по умолчанию.
        /// </summary>
        public QuartusMetadata ()
        {
            /// <summary>
            /// Инициализирует флаг quartusCompiled в false.
            /// </summary>
            quartusCompiled = false;
            /// <summary>
            /// Инициализирует deviceName значением по умолчанию "5CGXFC9E7F35C8".
            /// </summary>
            deviceName = "5CGXFC9E7F35C8";
        }
    }

    /// <summary>
    /// Класс, представляющий метаданные, связанные с базой данных.
    /// </summary>
    public class DatabaseMetadata
    {
        /// <summary>
        /// IP-адрес базы данных.
        /// </summary>
        /// <value>
        /// Строковое значение, представляющее IP-адрес базы данных.
        /// </value>
        public string dbIp { get; set; }
        /// <summary>
        /// Имя пользователя базы данных.
        /// </summary>
        /// <value>
        /// Строковое значение, представляющее имя пользователя базы данных.
        /// </value>
        public string dbUsername { get; set; }
        /// <summary>
        /// Пароль для доступа к базе данных.
        /// </summary>
        /// <value>
        /// Строковое значение, представляющее пароль для доступа к базе данных.
        /// </value>
        public string dbPassword { get; set; }
        /// <summary>
        /// Название базы данных.
        /// </summary>
        /// <value>
        /// Строковое значение, представляющее название базы данных.
        /// </value>
        public string dbName { get; set; }
        /// <summary>
        /// Порт базы данных.
        /// </summary>
        /// <value>
        /// Целочисленное значение, представляющее порт базы данных.
        /// </value>
        public int dbPort { get; set; }
        /// <summary>
        /// Флаг, указывающий, были ли данные записаны в базу данных.
        /// </summary>
        /// <value>
        /// true, если данные были записаны в базу данных; в противном случае — false.
        /// </value>
        public bool writtenToDB { get; set; }

        /// <summary>
        /// Конструктор класса DatabaseMetadata.
        /// Инициализирует свойства базы данных значениями по умолчанию.
        /// </summary>
        public DatabaseMetadata ()
        {
            /// <summary>
            /// Инициализирует dbIp пустой строкой.
            /// </summary>
            dbIp = "";
            /// <summary>
            /// Инициализирует dbUsername пустой строкой.
            /// </summary>
            dbUsername = "";
            /// <summary>
            /// Инициализирует dbPassword пустой строкой.
            /// </summary>
            dbPassword = "";
            /// <summary>
            /// Инициализирует dbName пустой строкой.
            /// </summary>
            dbName = "";
            /// <summary>
            /// Инициализирует dbPort значением -1.
            /// </summary>
            dbPort = -1;
            /// <summary>
            /// Инициализирует writtenToDB в false.
            /// </summary>
            writtenToDB = false;
        }
    }

    /// <summary>
    /// Класс, представляющий настройки проекта.
    /// Содержит все метаданные, относящиеся к проекту.
    /// </summary>
    public class ProjectSettings
    {
        /// <summary>
        /// Метаданные проекта.
        /// </summary>
        /// <value>
        /// Экземпляр класса ProjectMetadata, содержащий информацию о проекте.
        /// </value>
        public ProjectMetadata projectMetadata { get; set; }
        /// <summary>
        /// Метаданные, связанные с сериализацией графа и генерацией Verilog.
        /// </summary>
        /// <value>
        /// Экземпляр класса GraphVerilogMetadata.
        /// </value>
        public GraphVerilogMetadata graphVerilogMetadata { get; set; }
        /// <summary>
        /// Метаданные, связанные с компиляцией в Quartus.
        /// </summary>
        /// <value>
        /// Экземпляр класса QuartusMetadata.
        /// </value>
        public QuartusMetadata quartusMetadata { get; set; }
        /// <summary>
        /// Метаданные, связанные с базой данных.
        /// </summary>
        /// <value>
        /// Экземпляр класса DatabaseMetadata.
        /// </value>
        public DatabaseMetadata databaseMetadata { get; set; }

        /// <summary>
        /// Конструктор класса ProjectSettings.
        /// Инициализирует все метаданные проекта новыми экземплярами соответствующих классов.
        /// </summary>
        public ProjectSettings ()
        {
            /// <summary>
            /// Инициализирует projectMetadata новым экземпляром ProjectMetadata.
            /// </summary>
            projectMetadata = new ProjectMetadata ();
            /// <summary>
            /// Инициализирует graphVerilogMetadata новым экземпляром GraphVerilogMetadata.
            /// </summary>
            graphVerilogMetadata = new GraphVerilogMetadata ();
            /// <summary>
            /// Инициализирует quartusMetadata новым экземпляром QuartusMetadata.
            /// </summary>
            quartusMetadata = new QuartusMetadata ();
            /// <summary>
            /// Инициализирует databaseMetadata новым экземпляром DatabaseMetadata.
            /// </summary>
            databaseMetadata = new DatabaseMetadata ();
        }
    }
}